@@ -15,8 +15,8 @@ OC.L10N.register(
     "Keyboard shortcuts" : "Tipkovni prečaci",
     "Rename" : "Preimenuj",
     "Delete" : "Obriši",
-    "Previous" : "Prethodno",
     "by" : "od strane",
-    "Title" : "Naslov"
+    "Title" : "Naslov",
+    "Folder" : "Fasikla"
 },
 "nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
