@@ -14,6 +14,7 @@ OC.L10N.register(
     "Folder exists already!" : "Dosierujo jam ekzistas!",
     "Credentials" : "Aŭtentigiloj",
     "Subscribe" : "Aboni",
+    "Show all articles" : "Montri ĉiujn artikolojn",
     "Move" : "Movi",
     "Share" : "Kunhavigi",
     "Share with" : "Kunhavigi kun",
@@ -23,17 +24,15 @@ OC.L10N.register(
     "Settings" : "Agordo",
     "Documentation" : "Dokumentaro",
     "Keyboard shortcuts" : "Fulmoklavoj",
-    "Show all articles" : "Montri ĉiujn artikolojn",
     "Rename" : "Alinomigi",
     "Delete" : "Forigi",
     "Newest first" : "Pli novaj unue",
     "Oldest first" : "Malpli novaj unue",
-    "Previous" : "Antaŭa",
-    "Next" : "Posten",
     "Mark unread" : "Marki kiel nelegita",
     "Close details" : "Fermi detalojn",
     "by" : "de",
     "Open website" : "Malfermi TTT-ejon",
+    "Folder" : "Dosierujo",
     "Not available" : "Ne disponeble",
     "right" : "dekstro",
     "left" : "maldekstro",
