@@ -24,7 +24,6 @@ OC.L10N.register(
     "Subscribe" : "Suscribir",
     "Successfully updated news configuration" : "Configuración de noticias actualizada exitosamente",
     "Unable to update news config" : "No se pudo actualizar la configuración de noticias",
-    "Last job execution ran {relativeTime}. Something seems wrong." : "La última ejecución del trabajo fue hace {relativeTime}. Algo parece estar mal. ",
     "Last job ran {relativeTime}." : "El último trabajo se ejecutó {relativeTime}.",
     "Maximum read count per feed" : "Conteo máximo de lecturas por fuente",
     "Maximum redirects" : "Redirecciones máximas",
@@ -40,7 +39,7 @@ OC.L10N.register(
     "Maximum number of seconds to wait for an RSS or Atom feed to load; if it takes longer the update will be aborted." : "Tiempo máximo en segundos para esperar a que cargue una fuente RSS o Atom; si tarda más, se abortará la actualización.",
     "Interval in seconds in which the feeds will be updated." : "Intervalo en segundos en el que se actualizarán las fuentes.",
     "No article selected" : "Ningún artículo seleccionado",
-    "Please select an article from the list..." : "Por favor, seleccione un artículo de la lista...",
+    "Show all articles" : "Mostrar todos los artículos",
     "Move" : "Mover",
     "User Name" : "Nombre de usuario",
     "Share" : "Compartir",
@@ -60,7 +59,6 @@ OC.L10N.register(
     "Documentation" : "Documentación",
     "Keyboard shortcuts" : "Atajos del teclado",
     "Disable mark read through scrolling" : "Deshabilitar el marcar como leído al desplazar",
-    "Show all articles" : "Mostrar todos los artículos",
     "Reverse ordering (oldest on top)" : "Orden inverso (más antiguo arriba)",
     "Rename" : "Renombrar",
     "Delete" : "Borrar",
@@ -73,7 +71,6 @@ OC.L10N.register(
     "Default order" : "Ordenamiento predeterminado",
     "Enable full text" : "Habilitar texto completo",
     "Disable full text" : "Deshabilitar texto completo",
-    "Previous" : "Previo",
     "Share within Instance" : "Compartir dentro de la instancia",
     "Toggle star article" : "Alternar artículos marcados",
     "Close details" : "Cerrar detalles",
@@ -86,8 +83,9 @@ OC.L10N.register(
     "Keep article unread" : "Mantener el artículo como no-leído",
     "Toggle keep current article unread" : "Alternar mantener artículo actual como no leído",
     "Remove keep article unread" : "Eliminar mantener artículo como no leído",
-    "Not available" : "No disponible",
     "Please wait" : "Por favor aguarda",
+    "Folder" : "Carpeta",
+    "Not available" : "No disponible",
     "Keyboard shortcut" : "Atajo del teclado",
     "Action" : "Acción",
     "Jump to next article" : "Ir al artículo siguiente ",
@@ -107,7 +105,6 @@ OC.L10N.register(
     "No feeds found to add" : "No se encontraron fuentes para añadir",
     "Subscribe to" : "Suscribirse a",
     "Unread Articles" : "Artículos sin leer",
-    "If given, this service" : "Si se indica, este servicio",
     "Ajax or webcron mode detected! Your feeds will not be updated!" : "¡Se ha detectado el modo Ajax o webron! ¡Tus fuentes no serán actualizadas!",
     "How to set up the operating system cron" : "Cómo establecer las tareas programadas del sistema operativo",
     "Install and set up a faster parallel updater that uses the News app's update API" : "Instala y configura un actualizador en paralelo más rápido que use el API de actualización de la nueva aplicación"
