@@ -3,6 +3,7 @@ OC.L10N.register(
     {
     "Download" : "Sider",
     "Close" : "Mdel",
+    "Folder name" : "Isem n ukaram",
     "Username" : "Isem n useqdac",
     "Password" : "Awal uffir",
     "New folder" : "Akaram amaynut",
@@ -11,13 +12,13 @@ OC.L10N.register(
     "Default" : "Prédéfini(e)",
     "Off" : "Ur irmid ara",
     "Settings" : "Iɣewwaṛen",
+    "Keyboard shortcuts" : "Inegzumen n unasiw",
     "Rename" : "Beddel isem",
     "Delete" : "Kkes",
     "Newest first" : "Imaynuten d imezwura",
     "Oldest first" : "Iqbuṛen d imezwura",
-    "Previous" : "Ɣer deffir",
-    "Next" : "Uḍfir",
     "Title" : "Azwel",
+    "Folder" : "Akaram",
     "Refresh" : "Sismeḍ"
 },
 "nplurals=2; plural=(n != 1);");
