@@ -13,21 +13,21 @@ OC.L10N.register(
     "Folder exists already!" : "Dësen Dossier gëtt et schonns!",
     "Credentials" : "Credentials",
     "Subscribe" : "Umellen",
+    "Show all articles" : "All d'Artikelen uweisen",
     "Move" : "Verschieben",
     "Share" : "Deelen",
     "All articles" : "All Artikelen",
     "Explore" : "Erfuerschen",
     "Settings" : "Astellungen",
     "Documentation" : "Dokumentatioun",
-    "Show all articles" : "All d'Artikelen uweisen",
     "Rename" : "Ëm-benennen",
     "Delete" : "Läschen",
-    "Previous" : "Zeréck",
     "by" : "vun",
     "Play audio" : "Toun ofspillen",
     "Download audio" : "Toun eroflueden",
     "Download video" : "Video eroflueden",
     "Open website" : "Oppe Websäit",
+    "Folder" : "Dossier",
     "Jump to next article" : "Op den nächsten Artikel sprangen",
     "Jump to previous article" : "Op den Artikel vu virdru sprangen",
     "right" : "riets",
