@@ -35,7 +35,6 @@ OC.L10N.register(
     "How many redirects the feed fetcher should follow." : "Kiek kartų kanalų gaviklis turėtų sekti paskui peradresavimus.",
     "Article list" : "Straipsnių sąrašas",
     "Article details" : "Išsamiau apie straipsnį",
-    "Please select an article from the list..." : "Pasirinkite straipsnį iš sąrašo...",
     "Show all articles" : "Rodyti visus straipsnius",
     "Move" : "Perkelti",
     "User Name" : "Naudotojo vardas",
@@ -43,6 +42,7 @@ OC.L10N.register(
     "Share with" : "Bendrinti su",
     "Default" : "Numatytasis",
     "Please select a valid OPML file" : "Pasirinkite tinkamą OPML failą",
+    "File successfully uploaded" : "Failas įkeltas sėkmingai",
     "Rename Folder" : "Pervadinti aplanką",
     "Are you sure you want to delete?" : "Ar tikrai norite ištrinti?",
     "Mark read" : "Žymėti kaip skaitytą",
@@ -82,6 +82,7 @@ OC.L10N.register(
     "Last update" : "Paskutinis atnaujinimas",
     "Next update" : "Kitas atnaujinimas",
     "Title" : "Pavadinimas",
+    "Folder" : "Aplankas",
     "Keyboard shortcut" : "Spartusis klavišas",
     "Action" : "Veiksmas",
     "Jump to next article" : "Peršokti į kitą straipsnį",
