@@ -16,9 +16,12 @@ OC.L10N.register(
     "Move" : "Премести",
     "Share" : "Сподели",
     "Default" : "Предефиниран",
+    "Vertical" : "Вертикално",
+    "Horizontal" : "Хоризонтално",
     "Mark read" : "Означи како прочитано",
     "All articles" : "Сите статии",
     "Starred" : "Со ѕвезда",
+    "Explore" : "Истражувај",
     "Settings" : "Параметри",
     "Documentation" : "Документација",
     "Keyboard shortcuts" : "Кратенки преку тастатура",
@@ -26,34 +29,18 @@ OC.L10N.register(
     "Delete" : "Избриши",
     "Newest first" : "Новите прво",
     "Oldest first" : "Старите прво",
-    "Previous" : "Предходна",
-    "Next" : "Следна",
     "Mark unread" : "Означи како непрочитано",
     "by" : "од",
-    "from" : "од",
-    "{num} months ago" : "пред {num} месеци",
     "Open website" : "Отвори вебсајт",
+    "Title" : "Наслов",
+    "Folder" : "Папка",
     "Not available" : "Недостапно",
     "Keyboard shortcut" : "Кратенка преку тастатура",
+    "Action" : "Акција",
     "right" : "десно",
     "left" : "лево",
     "Refresh" : "Освежи",
     "Load next feed" : "Вчитај следен канал",
-    "Shift" : "Shift",
-    "Description" : "Опис",
-    "Folder" : "Папка",
-    "Go back" : "Назад",
-    "Create" : "Создај",
-    "Deleted feed" : "Избришан канал",
-    "Open feed URL" : "Отвори URL на каналот",
-    "Dismiss" : "Отфрли",
-    "Collapse" : "Собери",
-    "Subscriptions (OPML)" : "Претплати (OPML)",
-    "Import" : "Увези",
-    "Export" : "Извези",
-    "Unread/Starred Articles" : "Непрочитани/Означени статии",
-    "Error when importing: file does not contain valid JSON" : "Грешка при импортирање: датотеката не содржи валиден JSON",
-    "Help" : "Помош",
-    "Report a bug" : "Пријави грешка"
+    "Shift" : "Shift"
 },
 "nplurals=2; plural=(n % 10 == 1 && n % 100 != 11) ? 0 : 1;");
