@@ -10,28 +10,19 @@ OC.L10N.register(
     "Password" : "Passord",
     "New folder" : "Ny mappe",
     "Credentials" : "Credentials",
+    "Show all articles" : "Vis alle artiklar",
     "Move" : "Move",
     "Share" : "Del",
     "Settings" : "Innstillingar",
+    "Documentation" : "Dokumentasjon",
     "Keyboard shortcuts" : "Tastatursnarvegar",
-    "Show all articles" : "Vis alle artiklar",
     "Rename" : "Endra namn",
     "Delete" : "Ta bort",
     "Newest first" : "Nyaste fyrst",
     "Oldest first" : "Eldste fyrst",
     "by" : "av",
-    "from" : "frå",
     "Download video" : "Last ned video",
-    "Refresh" : "Oppfrisk",
-    "Description" : "Skildring",
     "Folder" : "Mappe",
-    "New Folder" : "Ny mappe",
-    "Create" : "Lag",
-    "Dismiss" : "Forkast",
-    "Import" : "Importer",
-    "Export" : "Eksporter",
-    "Help" : "Hjelp",
-    "Documentation" : "Dokumentasjon",
-    "Report a bug" : "Rapporter feil"
+    "Refresh" : "Oppfrisk"
 },
 "nplurals=2; plural=(n != 1);");
