@@ -1,11 +1,6 @@
 OC.L10N.register(
     "news",
     {
-    "Request failed, network connection unavailable!" : "Pedido falhou, ligação à rede indisponível!",
-    "Request unauthorized. Are you logged in?" : "Pedido não autorizado. Fez o início de sessão?",
-    "Token expired or app not enabled! Reload the page!" : "Token expirou ou aplicação não ativa! Recarregue a página!",
-    "Internal server error! Please check your data/nextcloud.log file for additional information!" : "Erro interno do servidor. Veja por favor o ficheiro na pasta data/nextcloud.log para mais informações!",
-    "Request failed, Nextcloud is in currently in maintenance mode!" : "Falha no pedido, Nextcloud está atualmente em modo de manutenção!",
     "News feeds" : "Feeds de notícias",
     "Unread articles" : "Artigos não lidos",
     "News" : "Notícias",
@@ -32,10 +27,13 @@ OC.L10N.register(
     "Update interval" : "Intervalo de atualização",
     "Use system cron for updates" : "Use o programador do sistema para as atualizações",
     "Disable this if you use a custom updater." : "Desative isto se é um sistema de atualizações feito à medida.",
+    "Show all articles" : "Mostrar todos os artigos",
     "Move" : "Mover",
     "Share" : "Partilhar",
     "Share with" : "Partilhar com",
     "Default" : "Predefinido",
+    "Vertical" : "Vertical",
+    "Horizontal" : "Horizontal",
     "Mark read" : "Marcar como lido",
     "All articles" : "Todos os artigos",
     "Starred" : "Marcado",
@@ -45,7 +43,6 @@ OC.L10N.register(
     "Keyboard shortcuts" : "Atalhos de teclado",
     "Article feed information" : "Informação da \"feed\" do artigo",
     "Disable mark read through scrolling" : "Desativar marcar ler através de movimento",
-    "Show all articles" : "Mostrar todos os artigos",
     "Reverse ordering (oldest on top)" : "Ordem inversa (antigos no topo)",
     "Rename" : "Renomear",
     "Delete" : "Apagar",
@@ -53,13 +50,10 @@ OC.L10N.register(
     "Open Feed URL" : "Abrir URL da Feed",
     "Newest first" : "Recentes primeiro",
     "Oldest first" : "Antigos primeiro",
-    "Previous" : "Anterior",
-    "Next" : "Seguinte",
     "Toggle star article" : "Alternar estrela do artigo",
     "Mark unread" : "Marcar como não lido",
-    "by" : "por",
-    "from" : "de",
     "shared by" : "partilhado por",
+    "by" : "por",
     "Play audio" : "Reproduzir áudio",
     "Download audio" : "Transferir áudio",
     "Download video" : "Transferir vídeo",
@@ -67,10 +61,12 @@ OC.L10N.register(
     "Keep article unread" : "Marcar artigo como não lido",
     "Toggle keep current article unread" : "Alternar manter o artigo atual como não lido",
     "Remove keep article unread" : "Remover marcação de artigo não lido",
-    "Not available" : "Não disponível",
+    "Please wait" : "Por favor aguarde",
     "Last update" : "Último refrescamento",
     "Time when the feed was last downloaded" : "A hora em que a \"feed\" foi transferida pela última vez",
     "Title" : "Título",
+    "Folder" : "Pasta",
+    "Not available" : "Não disponível",
     "Keyboard shortcut" : "Atalho de teclado",
     "Jump to next article" : "Ir para o artigo seguinte",
     "Jump to previous article" : "Ir para o artigo anterior",
@@ -86,37 +82,6 @@ OC.L10N.register(
     "Scroll to active navigation entry" : "Vá até a entrada de navegação ativa",
     "Shift" : "Shift",
     "How to set up the operating system cron" : "Como configurar o cron no sistema operativo",
-    "Install and set up a faster parallel updater that uses the News app's update API" : "Instale e configure um atualizador paralelo mais rápido que use a API de atualizações da aplicação Notícias",
-    "No articles available" : "Não há artigos disponíveis",
-    "No unread articles available" : "Não há artigos por ler disponíveis",
-    "Star article" : "Destacar artigo",
-    "Unstar article" : "Retirar destaque",
-    "No users found" : "Não foram encontrados utilizadores",
-    "Description" : "Descrição",
-    "Toggle expand article in compact view" : "Alternar expandir artigo na visualização compacta",
-    "Mark current article's feed/folder read" : "Marcar a pasta/\"feed\" do artigo atual como lida",
-    "Folder" : "Pasta",
-    "Go back" : "Voltar",
-    "New Folder" : "Nova Pasta",
-    "Create" : "Criar",
-    "Update failed more than 50 times" : "A atualização falhou mais de 50 vezes",
-    "Deleted feed" : "Feed eliminada",
-    "Undo delete feed" : "Anular eliminar feed",
-    "Menu" : "Menu",
-    "Open feed URL" : "Abrir URL da feed",
-    "Dismiss" : "Rejeitar",
-    "Collapse" : "Expandir",
-    "Deleted folder" : "Apagar pasta",
-    "Undo delete folder" : "Anular apagar pasta",
-    "Compact view" : "Visualização compacta",
-    "Expand articles on key navigation" : "Expandir artigos ao navegar por tecla",
-    "Subscriptions (OPML)" : "Subscrições (OPML)",
-    "Import" : "Importar",
-    "Export" : "Exportar",
-    "Error when importing: OPML is does neither contain feeds nor folders" : "Erro na importção: OPML não contém nem feeds nem pastas",
-    "Unread/Starred Articles" : "Artigos Não Lidos/Classificados",
-    "Error when importing: file does not contain valid JSON" : "Ocorreu um erro na importação: o ficheiro não contém JSON válido",
-    "Help" : "Ajuda",
-    "Report a bug" : "Reportar um erro"
+    "Install and set up a faster parallel updater that uses the News app's update API" : "Instale e configure um atualizador paralelo mais rápido que use a API de atualizações da aplicação Notícias"
 },
 "nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
