@@ -27,7 +27,8 @@ OC.L10N.register(
     "Subscribe" : "Prenumerera",
     "Successfully updated news configuration" : "Nyhetskonfigurationen har uppdaterats",
     "Unable to update news config" : "Kunde inte uppdatera nyhetskonfigurationen",
-    "Last job execution ran {relativeTime}. Something seems wrong." : "Senaste jobbexekveringen kördes {relativeTime}. Något verkar vara fel.",
+    "No job execution data available. The cron job may not be running properly." : "Ingen data om jobbexekvering tillgänglig. Cron-jobbet kanske inte körs korrekt.",
+    "Last job execution ran {relativeTime}. Something is wrong." : "Senaste jobbexekveringen kördes {relativeTime}. Något är fel.",
     "Last job ran {relativeTime}." : "Senaste jobbet kördes {relativeTime}.",
     "Maximum read count per feed" : "Maximalt läsantal per flöde",
     "Maximum redirects" : "Maximala omdirigeringar",
@@ -41,13 +42,17 @@ OC.L10N.register(
     "Enable this if you also want to delete unread articles." : "Aktivera detta om du också vill ta bort olästa artiklar.",
     "How many redirects the feed fetcher should follow." : "Hur många omdirigeringar flödet skall tillåtas följa.",
     "Maximum number of seconds to wait for an RSS or Atom feed to load; if it takes longer the update will be aborted." : "Maximalt antal sekunder att vänta på att RSS/Atom-flödet läses in; om det tar längre tid avbryts uppdateringen.",
+    "If provided, the URL of this service will be queried to display the feeds in the explore feed section. To fall back to the built in explore service, leave this input empty." : "Om det anges kommer URL:en för denna tjänst att användas för att visa flöden i avsnittet utforska flöden. Lämna detta fält tomt för att använda den inbyggda utforskningsfunktionen.",
     "Interval in seconds in which the feeds will be updated." : "Antal sekunder mellan uppdateringar av flödena.",
     "Use next update time for feed updates" : "Använd nästa uppdateringstid för flödesuppdateringar",
     "Enable this to use the calculated next update time for feed updates. Disable to update feeds based solely on the update interval." : "Aktivera detta för att använda den beräknade nästa uppdateringstiden för flödesuppdateringar. Inaktivera för att uppdatera flöden baserat enbart på uppdateringsintervallet.",
     "Article list" : "Artikellista",
     "Article details" : "Artikeldetaljer",
     "No article selected" : "Ingen artikel har valts",
-    "Please select an article from the list..." : "Välj en artikel från listan...",
+    "Please select an article from the list." : "Välj en artikel från listan.",
+    "Show all articles" : "Visa alla artiklar",
+    "Move feed" : "Flytta flöde",
+    "Please select the new folder" : "Välj den nya mappen",
     "Move" : "Flytta",
     "User Name" : "Användarnamn",
     "Share" : "Dela",
@@ -68,6 +73,7 @@ OC.L10N.register(
     "Are you sure you want to delete?" : "Är du säker på att du vill ta bort?",
     "Mark read" : "Markera som läst",
     "All articles" : "Alla artiklar",
+    "Recently viewed" : "Senast visade",
     "Starred" : "Stjärnmärkt",
     "Has feeds with errors!" : "Har flöden med fel!",
     "Explore" : "Utforska",
@@ -78,7 +84,6 @@ OC.L10N.register(
     "Display mode" : "Visningsläge",
     "Split mode" : "Delat läge",
     "Disable mark read through scrolling" : "Stäng av markerad som läst vid skrollning",
-    "Show all articles" : "Visa alla artiklar",
     "Reverse ordering (oldest on top)" : "Omvänd ordning (äldst överst)",
     "Disable automatic refresh" : "Inaktivera automatisk uppdatering",
     "Abonnements (OPML)" : "Prenumerationer (OPML)",
@@ -95,10 +100,10 @@ OC.L10N.register(
     "Disable full text" : "Avaktivera fulltext",
     "Mark as unread on update" : "Markera som oläst vid uppdatering",
     "Keep read status on update" : "Behåll lässtatus vid uppdatering",
+    "Sync disabled" : "Synk inaktiverad",
+    "Sync enabled" : "Synk aktiverad",
     "Previous Item" : "Föregående objekt",
-    "Previous" : "Föregående",
     "Next Item" : "Nästa objekt",
-    "Next" : "Nästa",
     "Share within Instance" : "Dela inom instans",
     "Toggle star article" : "Växla stjärnmärkning av artiklar",
     "Mark unread" : "Markera som oläst",
@@ -108,11 +113,11 @@ OC.L10N.register(
     "Play audio" : "Spela ljud",
     "Download audio" : "Hämta ljud",
     "Download video" : "Hämta video",
+    "Refresh list" : "Uppdatera listan",
     "Open website" : "Öppna webbplats",
     "Keep article unread" : "Behåll artikel oläst",
     "Toggle keep current article unread" : "Aktivera för att hålla aktuell artikel oläst",
     "Remove keep article unread" : "Ta bort behåll artikel oläst",
-    "Not available" : "Inte tillgänglig",
     "Importing feeds" : "Importerar flöden",
     "Please wait" : "Vänligen vänta",
     "Last update" : "Senaste uppdatering",
@@ -125,6 +130,8 @@ OC.L10N.register(
     "Error Count" : "Antal fel",
     "Number of errors that have occurred since the last successful feed update" : "Antal fel som har inträffat sedan den senaste framgångsrika flödesuppdateringen",
     "Title" : "Titel",
+    "Folder" : "Mapp",
+    "Not available" : "Inte tillgänglig",
     "Keyboard shortcut" : "Tangentbordsgenvägar",
     "Action" : "Ågärd",
     "Jump to next article" : "Hoppa till nästa artikel",
@@ -148,7 +155,6 @@ OC.L10N.register(
     "No feeds found to add" : "Inga flöden hittades att lägga till",
     "Subscribe to" : "Prenumerera på",
     "Unread Articles" : "Olästa artiklar",
-    "If given, this service" : "Om den ges, denna tjänst",
     "Ajax or webcron mode detected! Your feeds will not be updated!" : "Ajax- eller webcron-läge upptäckt! Dina flöden kommer inte uppdateras!",
     "How to set up the operating system cron" : "Hur man ställer in cron från operativsystemet",
     "Install and set up a faster parallel updater that uses the News app's update API" : "Installera och konfigurera en snabbare parallell uppdaterare som använder programmet Nyheter uppdatering API"
